SchemaSpy - gnss_data.public - Columns

Tables Relationships Utility Tables Constraints Anomalies Columns Donate

SchemaSpy Analysis of gnss_data.public - Columns | Generated by SchemaSpy

Generated by SchemaSpy on Fri Jul 28 14:55 EDT 2017 |
Legend: |
Primary key columns
Columns with indexes
Comments Legend

gnss_data.public contains 134 columns - click on heading to sort:

Table | Column | Type | Size | Nulls | Auto | Default | Comments
--- | --- | --- | --- | --- | --- | --- | ---
events | event_id | serial | 10 |  | √ | nextval('events_event_id_seq'::regclass) |
events | EventDate | timestamp | 29,6 | √ |  | now() |
antennas | AntennaCode | varchar | 22 |  |  |  |
stationinfo | AntennaCode | varchar | 22 |  |  |  |
antennas | AntennaDescription | varchar | 2147483647 | √ |  | null |
rinex | AntennaDome | varchar | 20 | √ |  | null |
rinex_extra | AntennaDome | varchar | 20 | √ |  | null |
stationinfo | AntennaEast | numeric | 12,4 | √ |  | null |
stationinfo | AntennaHeight | numeric | 6,4 | √ |  | null |
stationinfo | AntennaNorth | numeric | 12,4 | √ |  | null |
rinex | AntennaOffset | numeric | 131089 | √ |  | null |
rinex_extra | AntennaOffset | numeric | 131089 | √ |  | null |
rinex | AntennaSerial | varchar | 20 | √ |  | null |
rinex_extra | AntennaSerial | varchar | 20 | √ |  | null |
stationinfo | AntennaSerial | varchar | 20 | √ |  | null |
rinex | AntennaType | varchar | 20 | √ |  | null |
rinex_extra | AntennaType | varchar | 20 | √ |  | null |
stations | auto_x | numeric | 131089 | √ |  | null |
stations | auto_y | numeric | 131089 | √ |  | null |
stations | auto_z | numeric | 131089 | √ |  | null |
earthquakes | date | timestamp | 29,6 |  |  |  |
stationinfo | DateEnd | timestamp | 29,6 | √ |  | null |
stations | DateEnd | numeric | 7,3 | √ |  | null |
stationinfo | DateStart | timestamp | 29,6 |  |  |  |
stations | DateStart | numeric | 7,3 | √ |  | null |
earthquakes | depth | numeric | 131089 | √ |  | null |
apr_coords | DOY | timestamp | 29,6 |  |  |  |
gamit_soln | DOY | numeric | 131089 |  |  |  |
ppp_soln | DOY | numeric | 131089 |  |  |  |
ppp_soln_excl | DOY | numeric | 131089 |  |  |  |
events | EventDescription | text | 2147483647 | √ |  | null |
events | EventType | varchar | 6 | √ |  | null |
locks | filename | text | 2147483647 |  |  |  |
rinex | Filename | varchar | 20 | √ |  | null |
rinex_extra | Filename | varchar | 2147483647 |  |  |  |
apr_coords | FYear | numeric | 131089 | √ |  | null |
gamit_soln | FYear | numeric | 131089 | √ |  | null |
stations | Harpos_coeff_otl | text | 2147483647 | √ |  | null |
stations | height | numeric | 131089 | √ |  | null |
stationinfo | HeightCode | varchar | 2147483647 | √ |  | null |
rinex | Interval | numeric | 131089 | √ |  | null |
rinex_extra | Interval | numeric | 131089 | √ |  | null |
keys | isnumeric | bit | 1 | √ |  | null |
keys | KeyCode | varchar | 7 |  |  |  |
rinex_tank_struct | KeyCode | varchar | 7 | √ |  | null |
earthquakes | lat | numeric | 131089 |  |  |  |
stations | lat | numeric | 131089 | √ |  | null |
rinex_tank_struct | Level | int4 | 10 |  |  |  |
earthquakes | lon | numeric | 131089 |  |  |  |
stations | lon | numeric | 131089 | √ |  | null |
earthquakes | mag | numeric | 131089 | √ |  | null |
apr_coords | NetworkCode | varchar | 3 |  |  |  |
gamit_soln | NetworkCode | varchar | 3 |  |  |  |
locks | NetworkCode | varchar | 3 | √ |  | null |
networks | NetworkCode | varchar | 2147483647 |  |  |  |
ppp_soln | NetworkCode | varchar | 2147483647 |  |  |  |
ppp_soln_excl | NetworkCode | varchar | 3 |  |  |  |
rinex | NetworkCode | varchar | 2147483647 |  |  |  |
rinex_extra | NetworkCode | varchar | 2147483647 |  |  |  |
stationinfo | NetworkCode | varchar | 3 |  |  |  |
stations | NetworkCode | varchar | 3 |  |  |  |
networks | NetworkName | varchar | 2147483647 | √ |  | null |
rinex | ObservationDay | numeric | 131089 |  |  |  |
rinex_extra | ObservationDay | numeric | 131089 |  |  |  |
rinex | ObservationDOY | numeric | 131089 |  |  |  |
rinex_extra | ObservationDOY | numeric | 131089 |  |  |  |
rinex | ObservationETime | timestamp | 29,6 | √ |  | null |
rinex_extra | ObservationETime | timestamp | 29,6 | √ |  | null |
rinex | ObservationFYear | numeric | 131089 |  |  |  |
rinex_extra | ObservationFYear | numeric | 131089 |  |  |  |
rinex | ObservationMonth | numeric | 131089 |  |  |  |
rinex_extra | ObservationMonth | numeric | 131089 |  |  |  |
rinex | ObservationSTime | timestamp | 29,6 | √ |  | null |
rinex_extra | ObservationSTime | timestamp | 29,6 | √ |  | null |
rinex | ObservationYear | numeric | 131089 |  |  |  |
rinex_extra | ObservationYear | numeric | 131089 |  |  |  |
gamit_soln | Project | varchar | 20 |  |  |  |
stationinfo | RadomeCode | varchar | 7 |  |  |  |
receivers | ReceiverCode | varchar | 22 |  |  |  |
stationinfo | ReceiverCode | varchar | 22 |  |  |  |
receivers | ReceiverDescription | varchar | 22 | √ |  | null |
stationinfo | ReceiverFirmware | varchar | 10 | √ |  | null |
rinex | ReceiverFw | varchar | 20 | √ |  | null |
rinex_extra | ReceiverFw | varchar | 20 | √ |  | null |
rinex | ReceiverSerial | varchar | 20 | √ |  | null |
rinex_extra | ReceiverSerial | varchar | 20 | √ |  | null |
stationinfo | ReceiverSerial | varchar | 22 | √ |  | null |
rinex | ReceiverType | varchar | 20 | √ |  | null |
rinex_extra | ReceiverType | varchar | 20 | √ |  | null |
stationinfo | ReceiverVers | varchar | 22 | √ |  | null |
apr_coords | ReferenceFrame | varchar | 20 | √ |  | null |
ppp_soln | ReferenceFrame | varchar | 20 |  |  |  |
keys | rinex_col_in | varchar | 60 | √ |  | null |
keys | rinex_col_out | varchar | 2147483647 | √ |  | null |
apr_coords | se | numeric | 131089 | √ |  | null |
gamit_soln | sigmax | numeric | 131089 | √ |  | null |
ppp_soln | sigmax | numeric | 131089 | √ |  | null |
gamit_soln | sigmaxy | numeric | 131089 | √ |  | null |
ppp_soln | sigmaxy | numeric | 131089 | √ |  | null |
gamit_soln | sigmaxz | numeric | 131089 | √ |  | null |
ppp_soln | sigmaxz | numeric | 131089 | √ |  | null |
gamit_soln | sigmay | numeric | 131089 | √ |  | null |
ppp_soln | sigmay | numeric | 131089 | √ |  | null |
gamit_soln | sigmayz | numeric | 131089 | √ |  | null |
ppp_soln | sigmayz | numeric | 131089 | √ |  | null |
gamit_soln | sigmaz | numeric | 131089 | √ |  | null |
ppp_soln | sigmaz | numeric | 131089 | √ |  | null |
apr_coords | sn | numeric | 131089 | √ |  | null |
apr_coords | StationCode | varchar | 4 |  |  |  |
gamit_soln | StationCode | varchar | 4 |  |  |  |
locks | StationCode | varchar | 4 | √ |  | null |
ppp_soln | StationCode | varchar | 2147483647 |  |  |  |
ppp_soln_excl | StationCode | varchar | 4 |  |  |  |
rinex | StationCode | varchar | 2147483647 |  |  |  |
rinex_extra | StationCode | varchar | 2147483647 |  |  |  |
stationinfo | StationCode | varchar | 4 |  |  |  |
stations | StationCode | varchar | 4 |  |  |  |
stations | StationName | varchar | 40 | √ |  | null |
apr_coords | su | numeric | 131089 | √ |  | null |
keys | TotalChars | int4 | 10 | √ |  | null |
gamit_soln | VarianceFactor | numeric | 131089 | √ |  | null |
apr_coords | x | numeric | 131089 | √ |  | null |
gamit_soln | X | numeric | 131089 | √ |  | null |
ppp_soln | X | numeric | 12,4 | √ |  | null |
apr_coords | y | numeric | 131089 | √ |  | null |
gamit_soln | Y | numeric | 131089 | √ |  | null |
ppp_soln | Y | numeric | 12,4 | √ |  | null |
apr_coords | Year | timestamp | 29,6 |  |  |  |
gamit_soln | Year | numeric | 131089 |  |  |  |
ppp_soln | Year | numeric | 131089 |  |  |  |
ppp_soln_excl | Year | numeric | 131089 |  |  |  |
apr_coords | z | numeric | 131089 | √ |  | null |
gamit_soln | Z | numeric | 131089 | √ |  | null |
ppp_soln | Z | numeric | 12,4 | √ |  | null |